coerce_centre: Convert an object to a point in a suitable format

View source: R/coerce_centre.R

coerce_centreR Documentation

Convert an object to a point in a suitable format

Description

This is an internal helper used by the shape definition functions to process their centre parameters, where present. It is not intended to be used directly. Instead, it allows extensions to integrate with the shape functions so that they can accept new definitions.

Usage

coerce_centre(centre, ...)

Arguments

centre

Object defining the centre point.

...

Unused in the default implementation.

Value

A sfc object containins a single sf::st_point feature and with an appropriate CRS set.


ggmapinset documentation built on March 25, 2026, 5:06 p.m.